autofs-5.1.0 - fix gcc5 complaints

From: Ian Kent <raven@themaw.net>

gcc5 is not happy with the way dump_core() and master_get_logopt()
are declared inline, remove the inline and let the compiler decide.
---
 CHANGELOG           |    1 +
 daemon/spawn.c      |    2 +-
 include/automount.h |    2 +-
 include/master.h    |    2 +-
 lib/master.c        |    2 +-
 5 files changed, 5 insertions(+), 4 deletions(-)

diff --git a/CHANGELOG b/CHANGELOG
index 31f9af2..7ec5525 100644
--- a/CHANGELOG
+++ b/CHANGELOG
@@ -51,6 +51,7 @@
 - fix showmount search in auto.net.
 - remove obsolete comment in auto.net.
 - fix macro usage in lookup_program.c.
+- fix gcc5 complaints.
 
 04/06/2014 autofs-5.1.0
 =======================
diff --git a/daemon/spawn.c b/daemon/spawn.c
index bfb8cfc..c640d97 100644
--- a/daemon/spawn.c
+++ b/daemon/spawn.c
@@ -36,7 +36,7 @@ static pthread_mutex_t spawn_mutex = PTHREAD_MUTEX_INITIALIZER;
 
 #define MTAB_LOCK_RETRIES	3
 
-inline void dump_core(void)
+void dump_core(void)
 {
 	sigset_t segv;
 
diff --git a/include/automount.h b/include/automount.h
index ac6c4e3..447aba1 100644
--- a/include/automount.h
+++ b/include/automount.h
@@ -241,7 +241,7 @@ const char **copy_argv(int argc, const char **argv);
 int compare_argv(int argc1, const char **argv1, int argc2, const char **argv2);
 int free_argv(int argc, const char **argv);
 
-inline void dump_core(void);
+void dump_core(void);
 int aquire_lock(void);
 void release_lock(void);
 int spawnl(unsigned logopt, const char *prog, ...);
diff --git a/include/master.h b/include/master.h
index 164fd70..3f97acd 100644
--- a/include/master.h
+++ b/include/master.h
@@ -120,7 +120,7 @@ void master_notify_state_change(struct master *, int);
 int master_mount_mounts(struct master *, time_t, int);
 int dump_map(struct master *, const char *, const char *);
 int master_show_mounts(struct master *);
-extern inline unsigned int master_get_logopt(void);
+unsigned int master_get_logopt(void);
 int master_list_empty(struct master *);
 int master_done(struct master *);
 int master_kill(struct master *);
diff --git a/lib/master.c b/lib/master.c
index 2fa38c9..6c38b1c 100644
--- a/lib/master.c
+++ b/lib/master.c
@@ -1712,7 +1712,7 @@ int master_done(struct master *master)
 	return res;
 }
 
-inline unsigned int master_get_logopt(void)
+unsigned int master_get_logopt(void)
 {
 	return master_list ? master_list->logopt : LOGOPT_NONE;
 }
